import { useNavigate } from "react-router-dom";

export const useNavigation = () => {
    const navigate = useNavigate();

    const goToPagesAndOpenTab = (tabId: string, path: string) => {
    
        
        navigate(`${path}?tab=${tabId}`);
        
    };
    const goToTextsAndOpenCollapsible = (collapseId: string, path: string) => {
        
        navigate(`${path}?collapseId=${collapseId}`);
    };
    const goToPageWithTabAndCollapsible = ({ path, tabId, collapseId }: { path: string, tabId: string, collapseId?: string }) => {
        
        
        let url = `${path}?tab=${tabId}`;
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };
    const goToPageWithNestedTabs = ({ path, tabId, subTabId, collapseId }: { path: string, tabId: string, subTabId?: string, collapseId?: string }) => {
        
        
        let url = `${path}?tab=${tabId}`;
        if (subTabId) {
            url += `&subTab=${subTabId}`;
        }
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };



    const goToPageWithTabAndScroll = ({ path, tabId, scrollToId }: { path: string, tabId: string, scrollToId: string }) => {
        let url = `${path}?tab=${tabId}`;
        if (scrollToId) {
            url += `&scrollTo=${scrollToId}`;
        }
        navigate(url);
    };

    const goToPageAndScroll = (scrollToId: string, path: string) => {
        
        navigate(`${path}?scrollTo=${scrollToId}`);
    };

  

    const goToPlace = ({ path, scrollToId,tabId, subTabId, collapseId}: { path: string, scrollToId?: string, tabId?: string, subTabId?: string, collapseId?: string}) => {
        let url = `${path}`;
        if (tabId) {
            url += `?tab=${tabId}`;
            if (collapseId) {
                url += `&collapseId=${collapseId}`;
            }
            if (subTabId) {
                url += `&subTab=${subTabId}`;
            }
        }
        if (collapseId && !tabId) {
            url += `?collapseId=${collapseId}`;
            if (subTabId) {
                url += `&subTab=${subTabId}`;
            }
        }
        if (scrollToId && !tabId) {
            url += `?scrollTo=${scrollToId}`;
        } else if (scrollToId && tabId) {
            url += `&scrollTo=${scrollToId}`;
        } 
        navigate(url);
    }

    
    return { goToPlace,  goToPageAndScroll, goToPagesAndOpenTab, goToPageWithTabAndScroll, goToPageWithNestedTabs, goToPageWithTabAndCollapsible, goToTextsAndOpenCollapsible };
};
